/*   VPT OSC DEMO 1.0
by Xeracy (2/19/2011)
Required Libraries 
  oscP5     - http://www.sojamo.de/libraries/oscP5/
  controlP5 - http://www.sojamo.de/libraries/controlP5/
*/

import oscP5.*;        // oscP5 library
import netP5.*;        // included with oscP5 library
import controlP5.*;    // GUI library

OscP5 oscP5;                               // oscP5 object                      
NetAddress vptControllerAddress;           // VPT IP Address       
OscMessage myMessage = new OscMessage(""); // message object 
ControlP5 controlP5;                       // gui object

void setup() {
  size(520,150);
  frameRate(25);
  
  // use 127.0.0.1 if you are running this on the same computer as VPT. otherwise, use the IP address of the remote machine.
  vptControllerAddress = new NetAddress("127.0.0.1", 6666);   
  
  // add control sliders (name, min, max, initial, x, y, width, height)
  controlP5 = new ControlP5(this);
  controlP5.addSlider("sFade",0,1,1,20,20,15,100).setId(1);   
  controlP5.addSlider("sRed",0,1,1,70,20,15,100).setId(2);  
  controlP5.addSlider("sGreen",0,1,1,120,20,15,100).setId(3);  
  controlP5.addSlider("sBlue",0,1,1,170,20,15,100).setId(4);  
  controlP5.addSlider("sPos_X",-10,10,1,220,20,15,100).setId(5);  
  controlP5.addSlider("sPos_Y",-10,10,1,270,20,15,100).setId(6);  
  controlP5.addSlider("sScale_X",-10,10,1,320,20,15,100).setId(7);  
  controlP5.addSlider("sScale_Y",-10,10,1,370,20,15,100).setId(8);  
  controlP5.addSlider("sBlur",0,4,0,420,20,15,100).setId(9);  
  controlP5.addSlider("sRotate",0,360,0,470,20,15,100).setId(10);  


  // start oscP5, listening for incoming messages at port 10000 
  oscP5 = new OscP5(this,10000);
  
  background(0);  
  smooth();
}


void draw() {
  background(0); // keep the background clear.
}

//  easiest way to send a single OSC message
void sendMsg(String address, float value)
{
  myMessage.clear();                              // clear the message
  myMessage.setAddrPattern(address);              // set the address (ex: "/layer1/fade" 
  myMessage.add(value);                           // add an argument to the address
  println(address + " " + value);
  oscP5.send( myMessage, vptControllerAddress );  // send the message
}


// each slider calls its own event function:
public void sFade(float theValue) {
  sendMsg("/activelayer/fade",theValue); // lift the address directly from VPT's LFO help page [?] for list of addresses. 
}

public void sRed(float theValue) {
  sendMsg("/activelayer/red",theValue);
}

public void sGreen(float theValue) {
  sendMsg("/activelayer/green",theValue);
}

public void sBlue(float theValue) {
  sendMsg("/activelayer/blue",theValue);
}

public void sPos_X(float theValue) {
  sendMsg("/activelayer/pos_x",theValue);
}

public void sPos_Y(float theValue) {
  sendMsg("/activelayer/pos_y",theValue);
}

public void sScale_X(float theValue) {
  sendMsg("/activelayer/scale_x",theValue);
}

public void sScale_Y(float theValue) {
  sendMsg("/activelayer/scale_y",theValue);
}

public void sBlur(float theValue) {
  sendMsg("/activelayer/blur/level",theValue);
}

public void sRotate(float theValue) {
  sendMsg("/activelayer/txrot/rot",theValue);  
}



